@@ -1,4 +1,4 @@
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+//* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 
 /*
  *   Gnome Nibbles: Gnome Worm Game
@@ -40,7 +40,6 @@
 #include "board.h"
 #include "sound.h"
 #include "worm.h"
-#include "games-scores-dialog.h"
 #include "games-scores.h"
 
 GnibblesWorm *worms[NUMWORMS];
@@ -48,8 +47,6 @@ GnibblesWorm *worms[NUMWORMS];
 GnibblesBoni *boni = NULL;
 GnibblesWarpManager *warpmanager;
 
-GdkPixbuf *logo_pixmap = NULL;
-
 GdkPixbuf *wall_pixmaps[11] = { NULL, NULL, NULL, NULL, NULL,
   NULL, NULL, NULL, NULL, NULL,
   NULL
@@ -171,17 +168,6 @@ gnibbles_error (gchar *message)
   exit (1);
 }
 
-void
-gnibbles_load_logo (gint tilesize)
-{
-  if (logo_pixmap)
-    g_object_unref (logo_pixmap);
-
-  logo_pixmap = gnibbles_load_pixmap_file ("gnome-nibbles-logo.svg",
-                                           board->width * tilesize,
-                                           board->height * tilesize);
-}
-
 void
 gnibbles_init (void)
 {
@@ -343,43 +329,14 @@ gnibbles_keypress_worms (guint keyval)
   return FALSE;
 }
 
-void
-gnibbles_show_scores (GtkWidget * window, gint pos)
-{
-  static GtkWidget *scoresdialog = NULL;
-  gchar *message;
-
-  if (!scoresdialog) {
-    scoresdialog = games_scores_dialog_new (GTK_WINDOW (window),
-                                            highscores,
-                                            _("Nibbles Scores"));
-    games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
-                                                  (scoresdialog),
-                                                  _("Speed:"));
-  }
-  if (pos > 0) {
-    games_scores_dialog_set_hilight (GAMES_SCORES_DIALOG (scoresdialog), pos);
-    message = g_strdup_printf ("<b>%s</b>\n\n%s",
-                               _("Congratulations!"),
-                               pos == 1 ? _("Your score is the best!") :
-                               _("Your score has made the top ten."));
-    games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-                                     message);
-    g_free (message);
-  } else {
-    games_scores_dialog_set_message (GAMES_SCORES_DIALOG (scoresdialog),
-                                     NULL);
-  }
-
-  gtk_dialog_run (GTK_DIALOG (scoresdialog));
-  gtk_widget_hide (scoresdialog);
-}
-
 void
 gnibbles_log_score (GtkWidget * window)
 {
   gint pos;
 
+  if (properties->numworms > 1)
+    return;
+
   if (properties->human != 1)
     return;
 
@@ -391,19 +348,4 @@ gnibbles_log_score (GtkWidget * window)
 
   pos = games_scores_add_plain_score (highscores, worms[0]->score);
 
-  gnibbles_show_scores (window, pos);
-}
-
-
-void
-gnibbles_add_spec_bonus (gint t_x, gint t_y,
-                         gint t_type, gint t_fake, gint t_countdown)
-{
-  gnibbles_boni_add_bonus_final (boni, t_x, t_y, t_type, t_fake, t_countdown);
-}
-
-void
-gnibbles_remove_spec_bonus (gint x, gint y)
-{
-  gnibbles_boni_remove_bonus_final (boni, x, y);
 }
